@@ -14,6 +14,8 @@ class Meteonet(Dataset):
 
     URL = "https://github.com/meteofrance/meteonet/raw/master/data_samples"
 
-    home_page = "https://meteofrance.github.io/meteonet/"
+    home_page = "https://meteonet.umr-cnrm.fr"
 
     licence = "https://meteonet.umr-cnrm.fr/dataset/LICENCE.md"
+
+    documentation = "https://meteofrance.github.io/meteonet/"
